Net-DHCP version 0.7

  1. DOCS/ AND T/DATA FILES WARNING

Some files in the docs/ directory are copied from IANA. They may not be compatible with the MIT license. I have included them in the tar ball as-is for the sake of reference.

Currently these files are:

Some files in t/data are copied from various sources:

All other files are licensed as described at the bottom of this file.

Please remove the problem files if needed for distribution packaging etc.

You can fork and submit enhancements etc via https://github.com/djzort/Net-DHCP

  1. DESCRIPTION

Net::DHCP is a DHCP set of classes designed to handle basic DHCP handling. It can be used to develop either client, server or relays. It is composed of 100% pure Perl.

The author invites feedback on Net::DHCP. If there's something you'd like to have added, please let me know. If you find a bug, please send me the information described in the BUGS section below.

The original version of this module was written by Francis van Dun, and has been deeply reorganized.

  1. PREREQUISITES

Net::DHCP requires Perl 5.8.0 or higher.

  1. INSTALLATION

To install this module type the following:

perl Makefile.PL
make
make test
make install
  1. BUGS

If you find a bug, please report it to the author along with the following information:

The MIT License

Permission is hereby granted, free of charge, to any person
obtaining a copy of this software and associated
documentation files (the "Software"), to deal in the Software
without restriction, including without limitation the rights to
use, copy, modify, merge, publish, distribute, sublicense,
and/or sell copies of the Software, and to permit persons to
whom the Software is furnished to do so, subject to the
following conditions:

The above copyright notice and this permission notice shall
be included in all copies or substantial portions of the
Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT
WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR
PURPOSE AND NONINFRINGEMENT. IN NO EVENT
SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
CONNECTION WITH THE SOFTWARE OR THE USE OR
OTHER DEALINGS IN THE SOFTWARE.